@@ -288,11 +288,11 @@ def is_datetime_in_datetime_range(check_datetime: datetime, datetime_range: (dat
 
 
 def get_brand_name() -> str:
-    return our_get_env("BRAND_NAME")
+    return our_get_env("BRAND_NAME", raise_if_empty=True)
 
 
 def get_environment_name() -> str:
-    environment_name = our_get_env("ENVIRONMENT_NAME")
+    environment_name = our_get_env("ENVIRONMENT_NAME", raise_if_empty=True)
     EnvironmentName(environment_name)  # if invalid, raises ValueError: x is not a valid EnvironmentName
     return environment_name
 
@@ -311,15 +311,15 @@ def our_get_env(key: str, default: str = None, raise_if_not_found: bool = True,
 
 # TODO As only the database package uses those, let's move those three to the database package
 def get_sql_hostname() -> str:
-    return our_get_env("RDS_HOSTNAME")
+    return our_get_env("RDS_HOSTNAME", raise_if_empty=True)
 
 
 def get_sql_username() -> str:
-    return our_get_env("RDS_USERNAME")
+    return our_get_env("RDS_USERNAME", raise_if_empty=True)
 
 
 def get_sql_password() -> str:
-    return our_get_env("RDS_PASSWORD")
+    return our_get_env("RDS_PASSWORD", raise_if_empty=True)
 
 
 def get_dialog_jwt_secret_key() -> str:
@@ -343,35 +343,6 @@ def decode_jwt(token: str, key: str) -> dict:
     """key can be private / public"""
     return jwt.decode(token, key, algorithms=['HS256'])
 
-
-def obfuscate_log_dict(log_dict: dict) -> dict:
-    """
-    Obfuscate keys:
-    - %password%
-    - %secret%
-    - %token%
-    - %jwt%
-    - %e%mail%
-    - %phone%
-    - %name% (first / last / nick / user etc.)
-    - %address%
-    - %ssn%
-    """
-    environment_name = get_environment_name()
-    if environment_name == EnvironmentName.PLAY1.value:
-        return log_dict
-    obfuscated_log_dict = {}
-    for key, value in log_dict.items():
-        if isinstance(value, dict):
-            obfuscated_log_dict[key] = obfuscate_log_dict(value)
-        elif re.search(r'password|secret|token|jwt|e[\-_]?mail|phone|name|address|ssn', key, re.IGNORECASE):
-            # TODO Maybe we can reveal a small part
-            obfuscated_log_dict[key] = "***"
-        else:
-            obfuscated_log_dict[key] = value
-    return obfuscated_log_dict
-
-
 # TODO: add tests to the following functions
 
 def remove_digits(text: str) -> str:
